# CircuiTree
Genetic circuit design using Monte Carlo tree search

## Installation

### From a package repository
[Installation with `pip`/`conda` is not yet supported]

### From the GitHub repository

To install and use `circuitree` from the GitHub source code, first clone the repo into a directory.

```git clone https://github.com/pranav-bhamidipati/circuitree.git[ dir_name]```

Then, enter the directory and build the environment using the command-line tool `poetry`. Instructions for installation can be [found here](https://python-poetry.org/). by running `poetry install`. This will install a virtual environment in the virtualenv cache directory `POETRY_CACHE_DIR`. To activate this environment interactively as a nested shell, run `poetry shell`. Alternatively, you can run a command in the virtual environment with `poetry run <command>`. 

For instance, to launch a Jupyter notebook with `circuitree` pre-loaded, run `poetry run jupyter notebook`.

## Usage

See the [quick-start demo](examples/quick_start.ipynb).
